Learn R Programming

demic (version 2.0.0)

est_ptrs_subset: Get PTR estimates for output of the core pipeline on a subset of data

Description

Get PTR estimates for output of the core pipeline on a subset of data

Usage

est_ptrs_subset(p)

Value

a dataframe

  • sample: sample

  • est_ptr: PTR estimate

  • coefficient: coefficient of linear regression

  • pValue: p-value of linear regression

  • cor: correlation coefficient

  • correctY: corrected coverage

Arguments

p

is the pipeline named list